@@ -126,21 +126,25 @@ class Release:
         else:
             countries = self._countries
 
+        versions = {}
+
         if not version:
-            current = self._get_current_version(countries)
-            if current:
-                releases = self._get_releases_since(current)
-            else:
-                releases = self._get_releases_since(
-                    semver.VersionInfo.parse("0.1.0")
-                )  # default
-            if not releases:
-                logger.error(f"No new release found for project {self._project}!")
-                sys.exit(-1)
-            version = prompt_utils.ask_choices(
-                "Which version do you want to deploy?",
-                [{"name": f"{r.tag_name}", "value": r.tag_name} for r in releases],
-            )
+            for country in countries:
+                versions[country] = {}
+                versions[country] = self._get_current_version(country)
+
+        if self._tags_drifted(versions):
+            logger.warning("NOTE: one or more countries runs older tags.")
+
+        releases = self._extract_releases(versions)
+        if len(releases) == 0:
+            logger.error(f"No new release found for project {self._project}!")
+            sys.exit(0)
+
+        version = prompt_utils.ask_choices(
+            "Which version do you want to deploy?",
+            [{"name": f"{r.title}", "value": r.title} for r in releases],
+        )
 
         if not prompt_utils.ask_confirm(
             f"You're about to deploy {self._project} release {version} in {countries}, do you confirm?",
@@ -178,35 +182,40 @@ class Release:
         ):
             sys.exit(0)
 
-        self._start_deploy(version, country, rollback=True)
+        self._start_deploy(version, [country], rollback=True)
 
     def _get_current_version(self, country):
-        # get latest 10 tags
-        tags = self._github.get_tags(self._project)[0:9]
-        # retrieve specific promotion for all tags
-        builds = []
-        for tag in tags:
-            for b in self._drone.get_builds_from_tag(tag.name):
-                if (
-                    b["event"] == "promote"
-                    and b["status"] == "success"
-                    and b["deploy_to"] == f"deploy-{country}-production"
-                    and "params" in b
-                    and "DRONE_TAG" in b["params"]
-                ):
-                    builds.append(b)
+        try:
+            # get latest 10 tags
+            tags = self._github.get_tags(self._project)[0:9]
+            # retrieve specific promotion for all tags
+            builds = []
+            for tag in tags:
+                for b in self._drone.get_builds_from_tag(tag.name):
+                    if (
+                        b["event"] == "promote"
+                        and b["status"] == "success"
+                        and b["deploy_to"] == f"deploy-{country}-production"
+                        and "params" in b
+                        and "DRONE_TAG" in b["params"]
+                    ):
+                        builds.append(b)
 
-        # get latest build using build number as key
-        current_build = max(builds, key=lambda x: x["number"])
+            # get latest build using build number as key
+            current_build = max(builds, key=lambda x: x["number"])
 
-        if not current_build:
-            logger.error(f"Unable to determine current version for country {country}")
-            sys.exit(1)
+            if not current_build:
+                logger.error(
+                    f"Unable to determine current version for country {country}"
+                )
+                return None
 
-        v = semver.VersionInfo.parse(current_build["params"]["DRONE_TAG"])
-        logger.info(f"Current version for country {country}: {v}")
+            v = semver.VersionInfo.parse(current_build["params"]["DRONE_TAG"])
+            logger.info(f"Current version for country {country}: {v}")
 
-        return v
+            return v
+        except Exception:
+            return None
 
     def _create_release(self, new_version, message):
         new_release = self._repo.create_git_release(
@@ -246,6 +255,9 @@ class Release:
                 f"You can follow the build status here: {self._drone.get_build_url(promotion['number'])}"
             )
 
+            if rollback:
+                self._post_rollback()
+
     def _get_releases_since(self, threshold):
         releases = self._repo.get_releases().get_page(0)
 
@@ -315,6 +327,50 @@ class Release:
                     pass
         return repos_status
 
+    def _post_rollback(self):
+        logger.warning("--- !!!! ---")
+        logger.warning("Remember to revert git commit(s) if needed!")
+
+        if prompt_utils.ask_confirm(
+            "Do you want to lock production?",
+            default=True,
+        ):
+            self._captainhook.lock_project(self._project, "production")
+
+    def _tags_drifted(self, versions):
+        for country, version in versions.items():
+            for c, v in versions.items():
+                if country == c:
+                    continue
+                if version.compare(v) != 0:
+                    return True
+        return False
+
+    def _extract_releases(self, versions):
+        r = []
+        for _, version in versions.items():
+            releases = None
+            if version:
+                releases = self._get_releases_since(version)
+            else:
+                releases = self._get_releases_since(
+                    semver.VersionInfo.parse("0.1.0")
+                )  # default
+
+            if releases:
+                # check if releases already exist in the list, if not: append
+                if not self._is_release_duplicated(r, releases):
+                    r = r + releases
+
+        return r
+
+    def _is_release_duplicated(self, current, releases):
+        for c in current:
+            for rel in releases:
+                if c.title == rel.title:
+                    return True
+        return False
+
 
 def _bump_versions(current):
     return {
