@@ -7,7 +7,6 @@ from subprocess import CalledProcessError
 import sys
 import requests
 import yaml
-import semver
 
 from halo import Halo
 from suite_py.lib import logger
@@ -89,20 +88,30 @@ class DroneHandler:
         tags.sort(key=StrictVersion, reverse=True)
         return tags
 
-    def get_build_from_tag(self, tag):
+    def get_builds_from_tag(self, tag):
+        try:
+            builds = requests.get(
+                f"{BASEURL}/api/repos/primait/{self._repo}/builds?per_page=100&tag={tag}",
+                headers={"Authorization": f"Bearer {self._token}"},
+            ).json()
+
+            return builds
+        except Exception:
+            return []
+
+    def get_build_number_from_tag(self, tag):
         attempts = 0
         while attempts < 3:
 
             try:
                 builds = requests.get(
-                    f"{BASEURL}/api/repos/primait/{self._repo}/builds?per_page=100",
+                    f"{BASEURL}/api/repos/primait/{self._repo}/builds?per_page=100&tag={tag}",
                     headers={"Authorization": f"Bearer {self._token}"},
                 ).json()
 
                 for build in builds:
                     if build["event"] == "tag":
-                        if build["ref"].replace("refs/tags/", "") == tag:
-                            return build["number"]
+                        return build["number"]
             except Exception:
                 pass
 
@@ -122,7 +131,7 @@ class DroneHandler:
             sys.exit(-1)
 
     def promote_production(self, tag, target, querystring):
-        build = self.get_build_from_tag(tag)
+        build = self.get_build_number_from_tag(tag)
         if build:
             return self.promote(build, target, querystring)
 
@@ -131,38 +140,6 @@ class DroneHandler:
         )
         sys.exit(-1)
 
-    def get_latest_production_deploy(self, countries):
-        with Halo(text="Contacting drone...", spinner="dots", color="magenta"):
-            try:
-                builds = requests.get(
-                    f"{BASEURL}/api/repos/primait/{self._repo}/builds?per_page=100",
-                    headers={"Authorization": f"Bearer {self._token}"},
-                ).json()
-                try:
-                    return [
-                        {
-                            "country": country,
-                            "version": max(
-                                semver.VersionInfo.parse(b["params"]["DRONE_TAG"])
-                                for b in builds
-                                if b["event"] == "promote"
-                                and b["deploy_to"] == f"deploy-{country}-production"
-                                and "params" in b
-                                and "DRONE_TAG" in b["params"]
-                            ),
-                        }
-                        for country in countries
-                    ]
-                except Exception as e:
-                    logger.warning(f"get_latest_production_deploy: {e}")
-                    return []
-
-            except Exception as e:
-                logger.error(f"Unable to retrieve last deploy: {e}")
-                sys.exit(-1)
-
-            return []
-
     def launch_build(self, build):
         return requests.post(
             f"{BASEURL}/api/repos/primait/{self._repo}/builds/{build}",
