@@ -29,6 +29,9 @@ class GithubHandler:
         repo = self.get_repo(repo)
         return repo.get_branch(repo.get_pull(pr_number).head.ref)
 
+    def get_tags(self, repo):
+        return self.get_repo(repo).get_tags()
+
     def get_team_members(self, team_name=""):
         return self.get_organization().get_team_by_slug(team_name).get_members()
 
